@@ -312,8 +312,8 @@ def solve_steadystate_nse(A=None, J=None, JT=None, M=None,
             cdatstr = get_datastring(**datastrdict)
 
             norm_nwtnupd = dou.load_npa(cdatstr + '__norm_nwtnupd')
-            vel_k = dou.load_npa(cdatstr + '__vel')
             norm_nwtnupd_list.append(norm_nwtnupd)
+            vel_k = dou.load_npa(cdatstr + '__vel')
 
             if verbose:
                 print('found vel files')
@@ -463,6 +463,9 @@ def solve_steadystate_nse(A=None, J=None, JT=None, M=None,
         vp_k[cnv:] = -vp_k[cnv:]
         # pressure was flipped for symmetry
 
+        prvoutdict.update(dict(vp=vp_k))
+        dou.output_paraview(**prvoutdict)
+
         if normpicupd < vel_pcrd_tol:
             break
 
@@ -562,7 +565,7 @@ def solve_nse(A=None, M=None, J=None, JT=None,
               vel_pcrd_stps=4,
               krylov=None, krpslvprms={}, krplsprms={},
               clearprvdata=False,
-              useolddata=False,
+              # useolddata=False,  # not used anymore
               get_datastring=None,
               data_prfx='',
               paraviewoutput=False, plttrange=None, prvoutpnts=None,
@@ -572,6 +575,7 @@ def solve_nse(A=None, M=None, J=None, JT=None,
               dictkeysstr=False,
               treat_nonl_explicit=True, no_data_caching=True,
               treat_nonl_explct=False,  # TODO: remove deprecated option
+              datatrange=None, dataoutpnts=None,
               return_final_vp=False,
               return_as_list=False, return_vp_dict=False,
               return_y_list=False,
@@ -763,6 +767,17 @@ def solve_nse(A=None, M=None, J=None, JT=None,
     except AttributeError:
         pass
 
+    if datatrange is None and dataoutpnts is None:
+        datatrange = np.copy(trange).tolist()
+    elif datatrange is None:
+        cnts = trange.size  # TODO: trange may be a list...
+        filtert = np.arange(0, cnts, np.int(np.floor(cnts/dataoutpnts)))
+        datatrange = trange[filtert]
+    try:
+        datatrange = datatrange.tolist()
+    except AttributeError:
+        pass
+
     prvoutdict = dict(V=V, Q=Q, vp=None, t=None,
                       dbcinds=[dbcinds, glbcntbcinds],
                       dbcvals=[dbcvals],
@@ -831,15 +846,23 @@ def solve_nse(A=None, M=None, J=None, JT=None,
 
     if return_dictofpstrs or return_dictofvelstrs:
         def _atdct(cdict, t, thing):
+
+            if not t == datatrange[0]:
+                return
+            else:
+                datatrange.pop(0)
+
             if dictkeysstr:
                 cdict.update({'{0}'.format(t): thing})
             else:
                 cdict.update({t: thing})
+
     else:
         def _atdct(cdict, t, thing):
             pass
 
     def _gfdct(cdict, t):
+
         if dictkeysstr:
             return cdict['{0}'.format(t)]
         else:
@@ -1102,7 +1125,8 @@ def solve_nse(A=None, M=None, J=None, JT=None,
             elif return_final_vp:
                 return _toflagornottoflag((v_end, p_end))
             elif return_dictofvelstrs:
-                return _toflagornottoflag(expnlveldct)
+                dictofvelstrs.update(expnlveldct)
+                return _toflagornottoflag(dictofvelstrs)
             elif return_y_list:
                 return _toflagornottoflag(ylist)
             else:
